@@ -16,16 +16,20 @@
 
 import wx
 import wx.lib.inspection
+from update_check import isUpToDate
 
+from . import EXEC_DIR
 from .Ui_Main import UiMainWindow
 
-# from . import actorinfo, actorpack, bootup, language
-
 
 def main() -> None:
     app = wx.App()
     mainwindow = UiMainWindow(None, title="BotW Actor Tool")
     app.SetTopWindow(mainwindow)
+    version = EXEC_DIR / "__version__.py"
+    git_version = "https://raw.githubusercontent.com/GingerAvalanche/botw_actor_tool/master/botw_actor_tool/__version__.py"
+    if isUpToDate(version, git_version) == False:
+        mainwindow.SetNeedsUpdate()
     mainwindow.Show()
     # wx.lib.inspection.InspectionTool().Show()
     app.MainLoop()
